@@ -8,7 +8,6 @@ __author__ = 'https://github.com/akvilary'
 from typing import Optional, Self
 
 import re
-import uuid
 
 from . import helpers
 
@@ -69,7 +68,7 @@ class SqlContainer:
                 pattern = r'\$' + keyword + r'\b'
                 text = re.sub(
                     pattern,
-                    convert_to_sql_repr(value),
+                    helpers.convert_to_sql_repr(value),
                     text,
                 )
         return get_string_representation(text, self.wrapper_text)
@@ -88,58 +87,5 @@ class SqlContainer:
 def get_string_representation(text, wrapper_text) -> str:
     """Get text or wrap text by wrapper and return as string"""
     if wrapper_text is not None:
-        return get_text_wrapped(text, wrapper_text)
+        return helpers.get_text_wrapped(text, wrapper_text)
     return text
-
-
-def get_text_wrapped(text: str, wrapper_text: str) -> str:
-    """Wrap text by parentheses and add wrapper_text after them.
-    wrapper_text could be empty string (in that case you get text wrapped only by parentheses).
-    Params:
-        - text: str - text to be wrapped
-        - wrapper_text: str - string to be added after parentheses enclosing "text" argument.
-    """
-    return (
-        '('
-        + '\n'
-        + helpers.indent_lines(text, ind=2)
-        + '\n'
-        + ')'
-        + (
-            wrapper_text
-            if wrapper_text == ','
-            else (' ' + wrapper_text)
-            if wrapper_text
-            else ''
-        )
-    )
-
-
-def convert_to_sql_repr(value) -> str:
-    """Convert any value to sql representation"""
-    if isinstance(value, str):
-        return convert_to_sql_str(value)
-    if isinstance(value, (list, set, tuple)):
-        return str('ARRAY[' + ', '.join(convert_to_sql_repr(x) for x in value) + ']')
-    if isinstance(value, dict):
-        return convert_dict_to_sql_repr(value)
-    if isinstance(value, uuid.UUID):
-        return convert_to_sql_str(value)
-    return str(value)
-
-
-def convert_to_sql_str(value) -> str:
-    """Convert python string to sql string"""
-    return f"'{value}'"
-
-
-def convert_dict_to_sql_repr(dictionary: dict) -> str:
-    """Convert python dictionary to sql representation"""
-    converted = 'json_build_object('
-    unzipped = []
-    for key, value in dictionary.items():
-        for item in (key, value):
-            unzipped.append(convert_to_sql_repr(item))
-    converted += ', '.join(unzipped)
-    converted += ')'
-    return converted
